@@ -1,21 +1,22 @@
 package GNUpod::XMLhelper;
-#  Copyright (C) 2002-2007 Adrian Ulrich <pab at blinkenlights.ch>
+#  Copyright (C) 2002-2005 Adrian Ulrich <pab at blinkenlights.ch>
 #  Part of the gnupod-tools collection
 #
 #  URL: http://www.gnu.org/software/gnupod/
 #
-#    GNUpod is free software; you can redistribute it and/or modify
+#    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 3 of the License, or
+#    the Free Software Foundation; either version 2 of the License, or
 #    (at your option) any later version.
 #
-#    GNUpod is distributed in the hope that it will be useful,
+#    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # iTunes and iPod are trademarks of Apple
 #
@@ -25,15 +26,11 @@ use strict;
 use XML::Parser;
 use Unicode::String;
 use GNUpod::FooBar;
-use File::Glob ':glob';
 
 #Maximal length of a path
-#64 for ipod photo
-#55 for ipod mini
-#who cares, but don't go below 31! it would break getpath
-use constant MAX_PATHLENGTH => 49;
+use constant MAX_PATHLENGTH => 64;
 #Try X times to find a path
-use constant MAX_PATHLOOP => 2048;
+use constant MAX_PATHLOOP => 1024;
 
 ## Release 20050203
 
@@ -51,107 +48,106 @@ sub realpath {
 	return $mountp.$ipath;
 }
 
-
-##############################################
-# Finds a filename on the iPod
+###############################################
+# Get an iPod-safe path for filename
 sub getpath {
-	my($xconn, $source, $opts) = @_;
-	my $destination = undef;
-	
-	if($opts->{keepfile}) {
-		$destination = $source;  # Keep source path
+	my($mountp, $filename, $opts) = @_;
+	my $path = undef;
+
+	if($opts->{keepfile}) { #Don't create a new filename..
+		$path = $filename;
 	}
-	else {
-		my $clean_filename      = (split(/\//,$source))[-1];               # Extracts the filename
-		my ($current_extension) = $clean_filename =~ /\.([^.]*)$/;         # Current file extension
-		   $clean_filename      =~ tr/a-zA-Z0-9/_/c;                     # Remove bad chars
-		my $requested_ext       = ($opts->{extension} || $opts->{format}); # Checks if existing extension matches regexp
-		my @aviable_targets     = bsd_glob($xconn->{musicdir}."/*", GLOB_NOSORT);
-		
-		unless(int(@aviable_targets)) {
-			warn "No iPod folders found at $xconn->{mountpoint}, did you run gnupod_INIT.pl ?\n";
+	else { #Default action.. new filename to create 
+		my $test_extension = $opts->{extension} || $opts->{format}; #Test extension
+		my $name = (split(/\//, $filename))[-1];                    #Name
+		my $i = 0;                                                  #Count
+		my $mountpoint_length = length($mountp);                    #Length of the mountpoint
+		$name =~ tr/a-zA-Z0-9\./_/c;                                #CleanName for dumb Filesystems
+
+		#Hups, current filename has a wrong extension...
+		if($opts->{format} && $test_extension && ($name !~ /\.($test_extension)$/i)) {
+			my($ext) = $name =~ /\.([^.]*)$/;          #Get the current extension (maybe null)
+			warn "Warning: File '$name' has a wrong extension [$ext], changed extension to $opts->{format}\n";
+			$name =~ s/\.?$ext$/.$opts->{format}/;  #Replace current extension with newone
+		}
+ 
+		#### #Search a place for the MP3 file ####
+		# 1. Glob to find all dirs
+		## We don't cache this, we do a glob for each new file..
+		## Shouldn't be a waste if time.. We belive in the Cacheing of the OS ;)
+		my @aviable_targets = glob("$mountp/iPod_Control/Music/*");
+
+		# 2. Paranoia check..
+		unless(@aviable_targets) {
+			warn "No folders found, did you run gnupod_INIT.pl ?\n";
 			return undef;
 		}
-		if(length($current_extension) != 0) {
-			# -> Removes extension
-			$clean_filename = substr($clean_filename,0,(1+length($current_extension))*-1);
-		}
-		if($opts->{format} && $requested_ext && $current_extension !~ /$requested_ext/i) {
-			if(length($current_extension) != 0) {
-				# Only warn if file HAD an extension before
-				warn "Warning: $source has a wrong extension [$current_extension], changed extension to $opts->{format}\n";
-			}
-			$current_extension = $opts->{format};
-		}
+
+		# 3. Search
+		while(++$i) {
 		
-		for(my $i = 0; $i < MAX_PATHLOOP; $i++) {
-			my $dp_prefix  = sprintf("g%x_",$i);
-			my $dp_target  = $aviable_targets[int(rand(@aviable_targets))];
-			my $dp_path    = $dp_target."/".$dp_prefix;
-			my $dp_chrleft = MAX_PATHLENGTH - length($dp_path) + length($xconn->{mountpoint});
-			my $dp_ext     = ".$current_extension";
-			my $dp_extlen  = length($dp_ext);
-			next if $dp_chrleft < $dp_extlen; # No space for extension, checkout something else
-			$dp_path .= substr($clean_filename,($dp_chrleft-$dp_extlen)*-1).$dp_ext;
-			if(!(-e $dp_path) && open(TEST, ">", $dp_path)) {
-				close(TEST);
-				unlink($dp_path) or die "FATAL: Unable to unlink $dp_path : $!\n";
-				$destination = $dp_path;
+			if($i > MAX_PATHLOOP) { #Abort
+				warn "getpath() : No path for $name found, giving up!\n";
+				return undef;
+			}
+			
+			#Prefix for the filename
+			my $pdiff = $i."_";
+			#Target (including mountpoint)
+			my $target = $aviable_targets[int(rand(@aviable_targets))];
+			#-> $ipod_mountpoint/musicdir/$pdiff
+			my $tmp_ipodpath = $target."/".$pdiff;
+			#How many chars are left for the filename?
+			my $chars_left = MAX_PATHLENGTH - length($tmp_ipodpath) + $mountpoint_length;
+			next if $chars_left < 6; #We would like to get more than 6 chars for the filename (XXX.mp3)
+			#Note: Chars needs to be positive for this substr call!
+			$path = $tmp_ipodpath.substr($name,$chars_left*-1);
+			if( !(-e $path) && open(TESTFILE,">",$path) ) { #This is false if we would write to a globed file :)
+				close(TESTFILE);
+				unlink($path); #Maybe it's a dup.. we don't create empty files
 				last;
 			}
 		}
-	}
-	
-	
-	my $ipod_dest =  $destination;
-	   $ipod_dest =~ s/^$xconn->{mountpoint}(.+)/$1/;
-	   $ipod_dest =~ tr/\//:/;
-	return ($ipod_dest, $destination);
-}
+	} ## End default action
 
+#Remove mountpoint from $path
+my $ipath = $path;
+$ipath =~ s/^$mountp(.+)/$1/;
+
+#Convert /'s to :'s
+$ipath =~ tr/\//:/;
+return ($ipath, $path);
+}
 
 
 ################################################################
 # Escape chars
 sub xescaped {
-	use bytes;
 	my ($ret) = @_;
-	
 	$ret =~ s/&/&amp;/g;
 	$ret =~ s/"/&quot;/g;
-	$ret =~ s/\'/&apos;/g;
 	$ret =~ s/</&lt;/g;
 	$ret =~ s/>/&gt;/g;
-	$ret =~ tr/\000-\037//d;
-	#convert to XML encoded unicode
-	$ret =~ s/([\xC2-\xDF])([\x80-\xBF])/"&#x".sprintf("%x", ((ord($1) & 31) <<  6) +  (ord($2) & 63) ).";"/eg;
-	$ret =~ s/([\xE0-\xEF])([\x80-\xBF])([\x80-\xBF])/"&#x".sprintf("%x", ((ord($1) & 15) << 12) + ((ord($2) & 63) <<  6) +  (ord($3) & 63) ).";"/eg;
-	$ret =~ s/([\xF0-\xF4])([\x80-\xBF])([\x80-\xBF])([\x80-\xBF])/"&#x".sprintf("%x", ((ord($1) &  7) << 18) + ((ord($2) & 63) << 12) + ((ord($3) & 63) <<  6) + (ord($4) & 63) ).";"/eg;
-	# now everything left above 0x7f is illegal
-	my $in = $ret;
-	$ret =~ tr/\x80-\xff//d;
-	$ret =~ s/&#xfffe;//g; # inverted BOM that somehow slipped through
-	if ($in ne $ret) {
-		use Data::Dumper;
-		print "Something fishy was removed from your XML data. Here's the before/after data:\n";
-		print Dumper($in);
-		print Dumper($ret);
-	}
-	return $ret;
+	my $xutf = Unicode::String::utf8($ret)->utf8;
+	#Remove 0x00 - 0x1f chars (we don't need them)
+	$xutf =~ tr/\000-\037//d;
+	return $xutf;
 }
 
 
+
+
 ###############################################################
 # Create a new child (for playlists or file)
 # This is XML-Safe -> XDAT->{foo}->{data} or XDAT->{files}
-# is XML ENCODED UTF8 DATA
+# is XML ENCODED UTF8 DATA !!!!!!!!!!!!
 sub mkfile {
 	my($hr, $magic) = @_;
 	my $r = undef;
 
 	foreach my $base (keys %$hr) {
-		$r .= "<$base "; # can be file/add or such things. No need to escape it
-		#Copy the hash, because we do something to it
+		$r .= "<".xescaped($base)." ";
+		#Copy the has, because we do something to it
 		my %hcopy = %{$hr->{$base}};
 
 		#Create the id item if requested
@@ -163,7 +159,7 @@ sub mkfile {
 
 		#Build $r
 		foreach (sort(keys %hcopy)) {
-			$r .= "$_=\"".xescaped($hcopy{$_})."\" ";
+			$r .= xescaped($_)."=\"".xescaped($hcopy{$_})."\" ";
 		}
 
 		if($magic->{noend}) { $r .= ">" }
@@ -262,7 +258,7 @@ sub eventer {
 		my $xh = mkh($el,@it);         #Create a hash
 		@idpub[$xh->{file}->{id}] = 1; #Promote ID
 		main::newfile($xh);            #call sub
-	}
+	} 
 	elsif($href->{Context}[1] eq "" && $el eq "playlist") {
 		my $xh = mkh($el, @it); #Create hash
 		$xh->{$el}->{name} = "NONAME" unless $xh->{$el}->{name};
@@ -302,14 +298,8 @@ sub mkh {
 sub doxml {
 	my($xmlin, %opts) = @_;
 	return undef unless (-r $xmlin);
-	my $p;
-	my $ref = eval {
-		$p = new XML::Parser(ErrorContext => 0, Handlers=>{Start=>\&eventer});
-		$p->parsefile($xmlin);
-	};
-	if($@) {
-		die "An error occurred reading $xmlin :\n", $@ ;
-	}
+	my $p = new XML::Parser(Handlers=>{Start=>\&eventer});
+	   $p->parsefile($xmlin);
 	return $p;
 }
 
@@ -318,7 +308,7 @@ sub doxml {
 ######################################################
 # Write the XML File
 sub writexml {
-	my($rr, $opts) = @_;
+	my($rr) = @_;
 	my $out = $rr->{xml};
 	my $tmp_out = $out."_tmp_".int(time());
 
@@ -336,7 +326,7 @@ sub writexml {
 	#Print all playlists
 	foreach(getpl_attribs()) {
 		my $current_plname = $_->{name};
-		
+
 		if(my $shr = get_splpref($current_plname)) { #xmlheader present
 			print OUT "\n ".mkfile({smartplaylist=>$shr}, {return=>1,noend=>1})."\n";
 			### items
@@ -354,31 +344,18 @@ sub writexml {
 			print OUT " </playlist>\n";
 		}
 		else {
-			warn "XMLhelper.pm: bug found: unhandled plitem $_ inside $current_plname\n";
+			warn "XMLhelper.pm: bug found: unhandled plitem $_\n";
 		}
 	}
-
-	
-	print (OUT "</gnuPod>\n") or die "Unable to write to $tmp_out : $!\n"; # Hits Out-Of-Space condition
+	print OUT "</gnuPod>\n";
  
 	if(close(OUT)) {
 		if(-e $out) { #Backup old out file
 			rename($out, $out.".old") or warn "Could not move $out to $out.old\n";
 		}
-		rename($tmp_out, $out) or warn "Could not move $tmp_out to $out\n";
+	rename($tmp_out, $out) or warn "Could not move $tmp_out to $out\n";
 	}
-	else {
-		die "FATAL: Unable to close filehandle for $tmp_out : $!\n";
-	}
-	
-	# Don't trust OnTheGo data now (until mktunes has run)
-	GNUpod::FooBar::SetOnTheGoAsInvalid($rr);
-	
-	if($opts->{automktunes}) {
-		print "> Creating new iTunesDB\n";
-		GNUpod::FooBar::StartAutoMkTunes($rr);
-	}
-
+	GNUpod::FooBar::setINvalid_otgdata($rr);
 }
 
 1;
