@@ -1,21 +1,22 @@
 ###__PERLBIN__###
-#  Copyright (C) 2002-2007 Adrian Ulrich <pab at blinkenlights.ch>
+#  Copyright (C) 2002-2004 Adrian Ulrich <pab at blinkenlights.ch>
 #  Part of the gnupod-tools collection
 #
 #  URL: http://www.gnu.org/software/gnupod/
 #
-#    GNUpod is free software; you can redistribute it and/or modify
+#    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation; either version 3 of the License, or
+#    the Free Software Foundation; either version 2 of the License, or
 #    (at your option) any later version.
 #
-#    GNUpod is distributed in the hope that it will be useful,
+#    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # iTunes and iPod are trademarks of Apple
 #
@@ -32,11 +33,9 @@ print "gnupod_INIT.pl ###__VERSION__### (C) Adrian Ulrich\n";
 
 $opts{mount} = $ENV{IPOD_MOUNTPOINT};
 #Don't add xml and itunes opts.. we *NEED* the mount opt to be set..
-GetOptions(\%opts, "version", "help|h", "mount|m=s", "disable-convert|d", "france|f", "noask", "model=s");
-GNUpod::FooBar::GetConfig(\%opts, {model=>'s'}, "gnupod_INIT");
+GetOptions(\%opts, "version", "help|h", "mount|m=s", "disable-convert|d", "france|f");
 #gnupod_INIT does not read configuration files!
 
-
 usage() if $opts{help};
 version() if $opts{version};
 
@@ -73,14 +72,14 @@ Hit ENTER to continue or CTRL+C to abort
 EOF
 ##
 
-<STDIN> unless $opts{noask};
+<STDIN>;
  
  print "Creating directory structure on $opts{mount}\n\n";
  print "> AppFolders:\n";
  
- foreach( ($con->{rootdir}, $con->{musicdir},
-             $con->{itunesdir}, $con->{etc}) ) {
-   my $path = $_;
+ foreach( ("iPod_Control", "iPod_Control/Music",
+             "iPod_Control/iTunes", "iPod_Control/.gnupod") ) {
+   my $path = "$opts{mount}/$_";
    next if -d $path;
    mkdir("$path") or die "Could not create $path ($!)\n";
    print "+$path\n";
@@ -88,7 +87,7 @@ EOF
  
  print "> Music folders:\n";
  for(0..19) {
-   my $path = sprintf($con->{musicdir}."/F%02d", $_);
+   my $path = sprintf("$opts{mount}/iPod_Control/Music/F%02d", $_);
    next if -d $path;
    mkdir("$path") or die "Could not create $path ($!)\n";
    print "+$path\n";
@@ -96,14 +95,14 @@ EOF
 
  if($opts{france}) {
   print "> Creating 'Limit' file (because you used --france)\n";
-  mkdir("$con->{rootdir}/Device");
-  open(LIMIT, ">$con->{rootdir}/Device/Limit") or die "Failed: $!\n";
+  mkdir("$opts{mount}/iPod_Control/Device");
+  open(LIMIT, ">$opts{mount}/iPod_Control/Device/Limit") or die "Failed: $!\n";
    print LIMIT "216\n"; #Why?
   close(LIMIT);
  }
- elsif(-e "$con->{rootdir}/Device/Limit") {
+ elsif(-e "$opts{mount}/iPod_Control/Device/Limit") {
   print "> Removing 'Limit' file (because you didn't use --france)\n";
-  unlink("$con->{rootdir}/Device/Limit");
+  unlink("$opts{mount}/iPod_Control/Device/Limit");
  }
  else {
   print "> No 'Limit' file created or deleted..\n";
@@ -113,25 +112,19 @@ EOF
  
  GNUpod::XMLhelper::writexml($con);
 
- my $t2pfail = 0;
+ 
  if(-e $con->{itunesdb} && !$opts{'disable-convert'}) {
  #We have an iTunesDB, call tunes2pod.pl
   print "Found *existing* iTunesDB, running tunes2pod.pl\n";
-  $t2pfail = system("$con->{bindir}/tunes2pod.pl", "--force", "-m", $opts{mount});
+  system("$con->{bindir}/tunes2pod.pl --force -m $opts{mount}");
  }
  else {
  #No iTunesDB, run mktunes.pl
   print "No iTunesDB found, running mktunes.pl\n";
-  $t2pfail = system("$con->{bindir}/mktunes.pl", "-m" ,"$opts{mount}");
- }
- 
- if($t2pfail) {
-  print "\n Done\n ..Looks like something went wrong :-/\n";
- }
- else {
-  print "\n Done\n   Your iPod is now ready for GNUpod :)\n";
+  system("$con->{bindir}/mktunes.pl -m $opts{mount}");
  }
  
+ print "\n Done\n   Your iPod is now ready for GNUpod :)\n";
 }
 
 
@@ -154,7 +147,6 @@ Usage: gnupod_INIT.pl [-h] [-m directory]
                            Firmware 1.x (1st & 2nd generation)
                            You can also use mktunes.pl '--volume PERCENT'
                            to adjust the volume (Works with Firmware 1.x AND 2.x)
-       --noask             Do not wait for any user input
 
 Report bugs to <bug-gnupod\@nongnu.org>
 EOF
