@@ -27,8 +27,6 @@ use GNUpod::iTunesDB;
 use GNUpod::XMLhelper;
 use GNUpod::FooBar;
 use Getopt::Long;
-use File::Glob ':glob';
-
 use vars qw(%opts @keeper $plcref);
 
 
@@ -68,7 +66,7 @@ sub go {
  if(GNUpod::FooBar::_otgdata_broken($con)) { #Ok, On-The-Go data is ** BROKEN **
    warn "gnupod_otgsync.pl: Error: You forgot to run mktunes.pl, wiping broken On-The-Go data...\n";
    #Remove broken data.. live is hard..
-   unlink(bsd_glob($con->{onthego}, GLOB_NOSORT)) or warn "Could not remove $con->{onthego}, $!\n";
+   unlink($con->{onthego}) or warn "Could not remove $con->{onthego}, $!\n";
    unlink($con->{playcounts}) or warn "Could not remove $con->{playcounts}, $!\n"; 
 	 warn "Done!\n";
  }
@@ -98,30 +96,26 @@ sub go {
 #############################################
 # Add onthego contents to XML
 sub mkotg {
-	my(@otgrefs) = @_;
-
-	#Get all old playlists and create a new name
-	my $otggen = 1;
-	foreach(GNUpod::XMLhelper::getpl_attribs()) {
-		my $plname = $_->{name};
-		if($plname =~ /^On-The-Go (\d+)/) {
-			$otggen = ($1+1) if $otggen<=$1;
-		}
-	}
-
-	foreach (@otgrefs) {
-		my @xotg = @$_; #Change ref to array
-		next if int(@xotg) == 0; #Do not create empty OTG-Lists
-		GNUpod::XMLhelper::addpl("On-The-Go $otggen");
-		foreach(@xotg) {
-			my $otgid = $_+1;
-			my $plfh = ();
-			$plfh->{add}->{id} = $keeper[$otgid];
-			next unless $plfh->{add}->{id};
-			GNUpod::XMLhelper::mkfile($plfh,{"plname"=>"On-The-Go $otggen"});
-		}
-		$otggen++;
-	}
+ my(@xotg) = @_;
+ 
+ #Get all old playlists and create a new name
+ my $otggen = 1;
+ foreach(GNUpod::XMLhelper::getpl_attribs()) {
+   my $plname = $_->{name};
+   if($plname =~ /^On-The-Go (\d+)/) {
+    $otggen = ($1+1) if $otggen<=$1;
+   }
+ }
+ 
+ GNUpod::XMLhelper::addpl("On-The-Go $otggen");
+ 
+ foreach(@xotg) {
+  my $otgid = $_+1;
+  my $plfh = ();
+  $plfh->{add}->{id} = $keeper[$otgid];
+  next unless $plfh->{add}->{id};
+  GNUpod::XMLhelper::mkfile($plfh,{"plname"=>"On-The-Go $otggen"});
+ }
 
 }
 
